<?php declare(strict_types=1);

namespace Pinpoint\DropShipping\Controller\Adminhtml\Dropship;

use Pinpoint\DropShipping\Model\DropShipItemRepository;

class InlineEdit extends \Magento\Backend\App\Action
{
    protected $jsonFactory;
    /**
     * @var DropShipItemRepository
     */
    private $dropShipItemRepository;

    /**
     * @param \Magento\Backend\App\Action\Context $context
     * @param \Magento\Framework\Controller\Result\JsonFactory $jsonFactory
     */
    public function __construct(
        \Magento\Backend\App\Action\Context $context,
        DropShipItemRepository $dropShipItemRepository,
        \Magento\Framework\Controller\Result\JsonFactory $jsonFactory
    ) {
        parent::__construct($context);
        $this->jsonFactory = $jsonFactory;
        $this->dropShipItemRepository = $dropShipItemRepository;
    }

    /**
     * Inline edit action
     *
     * @return \Magento\Framework\Controller\ResultInterface
     */
    public function execute()
    {
        /** @var \Magento\Framework\Controller\Result\Json $resultJson */
        $resultJson = $this->jsonFactory->create();
        $error = false;
        $messages = [];

        if ($this->getRequest()->getParam('isAjax')) {
            $postItems = $this->getRequest()->getParam('items', []);
            if (!count($postItems)) {
                $messages[] = __('Please correct the data sent.');
                $error = true;
            } else {
                foreach (array_keys($postItems) as $modelId) {
                    /** @var \Pinpoint\DropShipping\Model\DropShipItem $model */
                    $model = $this->dropShipItemRepository->getById($modelId);
                    try {
                        //$model->setData(array_merge($model->getData(), $postItems[$modelid]));
                        $model->setStatus($postItems[$modelId]['status']);
                        $model->save();
                    } catch (\Exception $e) {
                        $messages[] = "[Dropship ID: {$modelId}]  {$e->getMessage()}";
                        $error = true;
                    }
                }
            }
        }

        return $resultJson->setData([
            'messages' => $messages,
            'error' => $error
        ]);
    }
}

